@@ -1,3 +1,5 @@
+import math
+
 def add(a, b):
     return a + b
 
@@ -11,4 +13,7 @@ def div(a, b):
     return a / b
 
 def sqr(a):
-    return a * a
\ No newline at end of file
+    return a * a
+
+def sqrt(a):
+    return math.sqrt(a)
\ No newline at end of file
